/*===============================================================================*
 * Copyright (C) 2020                                                            *
 *                                                                               *
 * Authors: Dario Menasce                        *
 *                                                                               *
 * INFN: Piazza della Scienza 3, Edificio U2, Milano, Italy 20126                *
 *                                                                               *
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
 * the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ================================================================================*/

// Come compilare:
// g++ -o makeAnalysis makeAnalysis.cpp analisi.cpp -I./ `root-config --cflags --libs`
//
// Per eseguire:
// ./makeAnalysis

#include <analisi.h>

//==================================================
int main(int argc, char** argv)
{
 TApplication app("analisi",0,0) ;

 string qualeEsempio = "makePlotTotale"; // Possibili valori:
                                         // makePlotTotale
                                         // makeSomePlots
                                         // userCodeExample
                                         // shoData
                                         // synopticView
 vector<string> regioniDaAnalizzare   ;
 vector<string> tipologieDaAnalizzare ;
 
 regioniDaAnalizzare  .push_back("Lombardia"            ) ;
// regioniDaAnalizzare  .push_back("Emilia Romagna"       ) ;
// regioniDaAnalizzare  .push_back("Veneto"               ) ;
 
 tipologieDaAnalizzare.push_back("totale_casi_"         ) ;
//  tipologieDaAnalizzare.push_back("totale_ospedalizzati_") ;
 
 Analisi * analisi = new Analisi("./rootFiles/makeTree.root") ;
 
 analisi->makeBranch    (                     ) ;
 analisi->readTree      (false                ) ;
 analisi->dumpAllData   (false                ) ;

 analisi->listaRegioni  (                     ) ;
 analisi->listaTipiDati (                     ) ;

 if(qualeEsempio == "makePlotTotale")
 {
  analisi->makePlotTotale(            "totale_casi_") ;
 }

 if(qualeEsempio == "makeSomePlots")
 { 
  analisi->bookHistograms(regioniDaAnalizzare    ,
                          tipologieDaAnalizzare) ;
  analisi->fillHistograms(regioniDaAnalizzare    ,
                          tipologieDaAnalizzare) ;
  analisi->draw          (true, false          ) ; // bool to include fits
                                                   // bool to plot in log scale
 }
 
 if(qualeEsempio == "userCodeExample")
 { 
  analisi->userCode      (regioniDaAnalizzare    ,
                          tipologieDaAnalizzare) ;
 }

 if(qualeEsempio == "showData")
 { 
  Analisi::mapDef theData = analisi->getData("Lombardia"     ,
                                             "totale_casi_") ;
  for(Analisi::mapDef::iterator it =theData.begin();
                                it!=theData.end()  ;
                                it++)
  {
   cout << __LINE__ << "] bin: " << it->first << "\tvalue: " << it->second << endl ;
  }
 }
 
 
 app.Run() ;
 return 0 ;
}

